import React from 'react';
import { render, fireEvent } from '@/test-utils/index';
import { NsAccordionItem, AccordionVariant } from '@/common/index';

describe('NsAccordionItem', () => {
    const title = 'Accordion Section Title';
    const content = 'Accordion Section Content';
    const contentElement = <div className="p-2">{content}</div>;
    it('1. renders title correctly', () => {
        const { getByText } = render(
            <NsAccordionItem
                type="jsx"
                variant={AccordionVariant.Basic}
                isOpen={false}
                toggleOpen={() => {}}
                title={title}
                content={contentElement}
                isChild={false}
                invert={false}
                level={1}
            />
        );
        expect(getByText(title)).toBeInTheDocument();
    });

    it('2. calls toggleOpen function when clicked on the section header', () => {
        const toggleOpen = jest.fn();
        const { getByText } = render(
            <NsAccordionItem
                type="jsx"
                variant={AccordionVariant.Basic}
                isOpen={false}
                toggleOpen={toggleOpen}
                title={title}
                content={contentElement}
                isChild={false}
                invert={false}
                level={1}
            />
        );
        fireEvent.click(getByText(title));
        expect(toggleOpen).toHaveBeenCalledTimes(1);
    });

    it('3. renders content when isOpen is true', () => {
        const { getByText } = render(
            <NsAccordionItem
                variant={AccordionVariant.Basic}
                isOpen={true}
                toggleOpen={() => {}}
                title={title}
                type="jsx"
                content={contentElement}
                isChild={false}
                invert={false}
                level={1}
            />
        );
        expect(getByText(content)).toBeInTheDocument();
    });

    it('4. when isOpen is false, renders jsx dom content within container with 0 height', () => {
        const { queryByText } = render(
            <NsAccordionItem
                type="jsx"
                variant={AccordionVariant.Basic}
                isOpen={false}
                toggleOpen={() => {}}
                title={title}
                content={contentElement}
                isChild={false}
                invert={false}
                level={1}
            />
        );
        const bodyElement = queryByText(content);
        expect(bodyElement?.parentNode).toHaveStyle('height:0px;');
    });
});
