import React, { ReactElement } from 'react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import type { Meta, StoryObj } from '@storybook/react';

import { NsAutocomplete } from '../';
import { NsIcon } from '../../icon';
import { AutocompleteMockList } from '../mock/MockData';
import { NoCloseAutoComplete } from './NoCloseAutoComplete';
import { RenderAutoComplete } from './RenderAutoComplete';

type ComponentType = typeof NsAutocomplete;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsAutocomplete',
    component: NsAutocomplete,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text',
        },
        options: {
            description: 'An array of objects representing the available options for the autocomplete.',
        },
        OptionsUI: {
            description: '(optional): A custom component to render each option in the dropdown.',
        },
        loading: {
            description: '(optional): A boolean indicating whether the autocomplete is in a loading state.',
        },
        noOptionsText: { description: '(optional): The text to display when there are no options available.' },
        onSelect: { description: '(optional): A callback function to be called when an option is selected.' },
        onChange: { description: '(optional): A callback function to be called when the input value changes.' },
        clear: { description: '(optional): An object containing properties for the clear button.' },
        seeMore: { description: '(optional): An object containing properties for the "see more" button.' },
        placeholder: { description: '(optional): The placeholder text for the input field.' },
        className: { description: '(optional): Additional CSS class name(s) for the autocomplete component.' },
        iconStart: {
            description: '(optional): An icon or React node to be displayed at the start of the input field.',
        },
        iconEnd: { description: '(optional): An icon or React node to be displayed at the end of the input field.' },
        inputValue: { description: ' The current value of the input field.' },
        value: { description: ': The currently selected option.' },
        isFilterEnabled: { description: ' (optional): A boolean indicating whether filtering of options is enabled.' },
    },
    args: {
        options: AutocompleteMockList,
        seeMore: {
            text: 'See More Results',
            show: true,
            onSeeMore: () => {
                throw new Error('Function not implemented.');
            },
        },
        clear: {
            text: 'Clear Recent Searches',
            show: true,
            onClear: () => {
                throw new Error('Function not implemented.');
            },
        },
        iconStart: (<NsIcon name="search" />) as ReactElement,
        iconEnd: (<NsIcon name="roundedClose" size="small" colorOverride="#F5F5F5" />) as ReactElement,
        placeholder: 'Search',
        fullWidth: false,
    },
} as MetaStory;

export const Autocomplete: Story = {
    render: RenderAutoComplete,
};

export const WithoutClose: Story = {
    render: NoCloseAutoComplete,
};
