import { NsAutocompleteProps, OptionsProps } from '../types';
import { IconButton } from '@mui/material';
import React, { useState, SyntheticEvent } from 'react';

import { NsAutocomplete } from '..';
import { NsIcon } from '../../icon';
import { OptionUiComponent } from '../mock/MockUI';

const PAGE_SIZE = 6;

export const RenderAutoComplete = (args: NsAutocompleteProps) => {
    const [selectedOption, setSelectedOption] = useState<string | OptionsProps | null>(null);
    const [searchTerms, setSearchTerms] = useState<string>('');
    const [pageNo, setPageNo] = useState(PAGE_SIZE);

    const onSeeMoreHandler = () => {
        setPageNo(PAGE_SIZE + PAGE_SIZE);
    };

    const AutoCompleteProps = {
        ...args,
        seeMore: {
            ...args.seeMore,
            onSeeMore: onSeeMoreHandler,
        },
    } as NsAutocompleteProps;

    const onChange = (event: SyntheticEvent<Element, Event>, value: string | OptionsProps | null) => {
        setSelectedOption(value);
        setSearchTerms((value = ''));
    };

    const onInputChange = (event: SyntheticEvent<Element, Event>, newValue: string) => {
        setSearchTerms(newValue);
    };

    const onInputClear = () => {
        setSelectedOption(null);
        setSearchTerms('');
    };

    return (
        <div>
            <NsAutocomplete
                {...AutoCompleteProps}
                options={args.options.slice(0, pageNo)}
                onInputChange={onInputChange}
                onChange={onChange}
                OptionsUI={OptionUiComponent}
                iconEnd={
                    <IconButton onClick={onInputClear}>
                        <NsIcon name="roundedClose" size="xLarge" colorOverride="#F5F5F5" />
                    </IconButton>
                }
                value={selectedOption}
                inputValue={searchTerms}
            />
        </div>
    );
};
