/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsBreadcrumb.tsx
 * @description NsBreadcrumb component with a navigation items array props
 */

import {
    PropsWithChildren,
    ReactElement,
} from 'react';

import { useTheme } from '@mui/material/styles';
import { ColorUtils } from '@nuskin/foundation-theme';

import {
    NsIcon,
    NsTypography,
} from '../';
import {
    BreadcrumbContainer,
    BreadcrumbItem,
    BreadcrumbList,
    BreadcrumbStyledLink,
} from './NsBreadcrumb.styled';
import {
    ItemProps,
    NsBreadcrumbProps,
} from './types.d';

const { color } = ColorUtils;

const NsBreadcrumb = (props: PropsWithChildren<NsBreadcrumbProps>):ReactElement => {
    const { items, underline = true, separator = 'chevronRight' } = props;

    const theme = useTheme();
    const neutral80 = color('neutral', '80')({ theme });
    const neutral60 = color('neutral', '60')({ theme });

    const getLabel = (item: ItemProps) => {
        if (item?.href) {
            return (
                <NsTypography variant="h6" colorOverride={neutral60}>
                    <BreadcrumbStyledLink
                        underlineVisibility={underline}
                        href={item.href}
                        underlineOnHover={!underline}
                    >
                        {item.icon ? (
                            <NsIcon name={item.icon} size="medium" testId="nav-icon" colorOverride={neutral60} />
                        ) : null}
                        {item.label}
                    </BreadcrumbStyledLink>
                </NsTypography>
            );
        } else {
            return (
                <NsTypography variant="h6" weight="bold" colorOverride={neutral80}>
                    {item.label}
                </NsTypography>
            );
        }
    };

    return (
        <BreadcrumbContainer aria-label="breadcrumb">
            <BreadcrumbList>
                {items?.map((item: ItemProps, index: number) => (
                    <BreadcrumbItem key={item.label}>
                        {getLabel(item)}
                        {index !== items.length - 1 ? (
                            <NsIcon
                                className={separator === 'slash' && 'slashIcon'}
                                name={separator}
                                size="medium"
                                colorOverride={neutral80}
                            />
                        ) : null}
                    </BreadcrumbItem>
                ))}
            </BreadcrumbList>
        </BreadcrumbContainer>
    );
};

export default NsBreadcrumb;
