import {
    PropsWithChildren,
    ReactElement,
} from 'react';

import { useTheme } from '@mui/material/styles';

import { NsIcon } from '../icon';
import { StyledButton } from './NsButton.styled';
import { NsButtonProps } from './types.d';

const NsButton = ({ children, darkModeEnabled = true, ...props }: PropsWithChildren<NsButtonProps>):ReactElement => {
    const { color, startIconName, endIconName, variant } = props;
    const { palette } = useTheme();
    // TODO: remove any
    const btnColor = color && (palette as any)?.[color] ? color : 'primary';
    let iconColor = btnColor;
    if (variant === 'contained') {
        if (btnColor === 'secondary') {
            iconColor = 'primary';
        } else {
            iconColor = 'secondary';
        }
    }
    let startIcon = props.startIcon;
    if (!startIcon && startIconName) {
        startIcon = <NsIcon name={startIconName} color={iconColor} size={props.size} />;
    }
    let endIcon = props.endIcon;
    if (!endIcon && endIconName) {
        endIcon = <NsIcon name={endIconName} color={iconColor} size={props.size} />;
    }

    return (
        <StyledButton
            {...props}
            startIcon={startIcon}
            endIcon={endIcon}
            color={btnColor}
            disableRipple
            darkModeEnabled={darkModeEnabled}
        >
            {children}
        </StyledButton>
    );
};

export default NsButton;
