type ContainedParams = {
    backgroundColor: string;
    textColor: string;
    hovered: string;
    pressed: string;
    focused: string;
};

export function generateContainedStyle({
    backgroundColor,
    textColor,
    hovered,
    pressed,
    focused,
}: ContainedParams): Record<string, any> {
    return {
        backgroundColor,
        color: `${textColor} !important`,
        '&:hover': {
            backgroundColor: `${hovered}`
        },
        '&:active': {
            backgroundColor: `${pressed}`
        },
        '&:focus': {
            backgroundColor: `${focused}`
        }
    };
}
type OutlinedParams = {
    borderColor: string;
    hovered: string;
    pressed: string;
    activeColor: string;
};
export function generateOutlinedStyle({ borderColor, hovered, pressed, activeColor }: OutlinedParams) {
    return {
        borderColor: `${borderColor}`,
        color: `${borderColor}`,
        '&:hover': {
            borderColor: `${hovered}`,
            color: `${borderColor}`
        },
        '&:active': {
            borderColor: `${pressed}`,
            color: `${activeColor}`
        }
    }
}

type TextParams = {
    underlineColor: string;
    hovered: string;
    pressed: string;
};

export function generateTextStyles({ underlineColor, hovered, pressed }: TextParams):  Record<string, any> {
    return {
        textDecoration: 'underline 1px !important',
        textUnderlineOffset: '4px',
        minWidth: 'auto',
        backgroundColor: 'transparent !important',
        textDecorationColor: `${underlineColor}`,
        color: `${underlineColor}`,
        '&:hover': {
            color: `${hovered}`,
            textDecorationColor: `${hovered}`,
            backgroundColor: 'transparent !important',
            border: 0,
        },
        '&:active, &:focus': {
            color: `${underlineColor}`,
            textDecorationColor: `${pressed}`,
            border: 'none !important',
        }
    };
}

export function generateIconOnlyStyles() {
    return {
        padding: '10px',
        minWidth: 'unset',
    };
}
