import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsTypography } from '../';
import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsAwardCardProps = {
    title: string;
    awardName: string;
    mediaOutlet: string;
    backgroundImageDetail: BynderImageDataType;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        alignItems: 'center',
        width: '160px',
        height: 'auto',
        '.image': {
            width: '160px',
            height: 'auto',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            textAlign: 'center',
            alignItems: 'center',
            marginTop: '25px',
        },
        '.content-text': {
            marginTop: '20px',
        },
        '.action-link': {
            marginTop: '10px',
            alignSelf: 'start',
        },
    };
});

export default function NsAwardCard({
    title,
    awardName,
    mediaOutlet,
    backgroundImageDetail,
    className,
}: NsAwardCardProps): ReactElement {
    return (
        <CardContainer className={className} role="award-card" component="div" data-testid="award-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <NsTypography weight="normal" className="title" variant="h5">
                    {title}
                </NsTypography>
                <NsTypography className="content-text" variant="body-l">
                    {awardName}
                </NsTypography>
                <NsTypography className="content-text" variant="body-l">
                    {mediaOutlet}
                </NsTypography>
            </div>
        </CardContainer>
    );
}
