import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsPostProps = {
    text: string;
    body: string;
    backgroundImageDetail: BynderImageDataType;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        maxWidth: '165px',
        height: '272px',
        backgroundColor: '#fff',
        '.image': {
            height: '180px',
            overflow: 'hidden',
            objectFit: 'contain',
        },
        '.content': {
            padding: '20px',
            display: 'flex',
            flexDirection: 'column',
            minHeight: '92px',
            maxHeight: '92px',
            justifyContent: 'space-around',
        },
        '.body-title': {
            fontSize: '18px',
            fontWeight: 600,
            display: '-webkit-box',
            '-webkit-box-orient': 'vertical',
            '-webkit-line-clamp': '1',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
            margin: 0,
        },
        '.body-text': {
            fontSize: '12px',
            fontWeight: 700,
            display: '-webkit-box',
            '-webkit-box-orient': 'vertical',
            '-webkit-line-clamp': '1',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
            color: '#8C8C8C',
            margin: 0,
        },
    };
});

const NsPost = ({ text, body, backgroundImageDetail, className }: NsPostProps): ReactElement => {
    return (
        <CardContainer className={className} data-testid="post-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <article className="content">
                <h2 className="body-title" title={text}>
                    {text}
                </h2>
                <p className="body-text" title={body?.substring(0, 80)}>
                    {body}
                </p>
            </article>
        </CardContainer>
    );
};
export default NsPost;
