import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsSmallFullCardProps = {
    title: string;
    subtitle: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundColor: '#fff',
        display: 'flex',
        maxHeight: '320px',
        maxWidth: '375px',
        overflow: 'hidden',
        position: 'relative',
        '.image': {
            width: '100%',
            height: '100%',
            objectFit: 'cover',
        },
        '.gradientOverlay': {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            background: 'linear-gradient(to top, rgba(0,0,0,0.6) 0%, transparent 50%);',
        },
        '.content': {
            position: 'absolute',
            height: '100%',
            width: '100%',
            padding: '40px 40px 25px 30px',
            display: 'flex',
            flexDirection: 'column',
        },
        '.subtitle': {
            color: '#fff',
            fontSize: '11px',
            fontWeight: '400',
            marginTop: 'auto',
        },
        '.title': {
            color: '#fff',
            fontSize: '26px',
            fontWeight: '400',
            marginTop: '20px',
        },
        '.cta': {
            marginTop: '20px',
            maxWidth: '208px',
            borderRadius: '4px',
            overflow: 'hidden',
        },
    };
});

export default function NsSmallFullCard({
    title,
    subtitle,
    backgroundImageDetail,
    button,
    className,
}: NsSmallFullCardProps): ReactElement {
    return (
        <CardContainer className={className} role="small-full-card" component="div" data-testid="small-full-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="gradientOverlay"></div>
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
