import React, { ReactElement, useState } from 'react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { expect } from '@storybook/jest';
import type { Meta, StoryObj } from '@storybook/react';
import { within } from '@storybook/testing-library';

import { NsCheckbox } from './';

type ComponentType = typeof NsCheckbox;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

const labelText = 'Checkbox Label';
// In this case, we're only passing the label prop.
export default {
    title: 'Components/Inputs/NsCheckbox',
    component: NsCheckbox,
    decorators: [withCenterDecorator],
    argTypes: {
        disabled: { control: 'boolean' },
        flag: {
            message: { control: 'text' },
            color: { control: 'select' },
        },
    },
    args: {
        label: labelText,
        disabled: false,
        ariaLabel: 'primary checkbox',
        size: 'medium',
        flag: {
            message: 'New',
            color: 'accentColorA',
        },
    },
} as MetaStory;

const RenderCheckbox = (args: any): ReactElement => {
    const [isChecked, setIsChecked] = useState(false);
    const handleChange = (event: { target: { checked: boolean } }) => {
        const isChecked = event.target.checked;
        setIsChecked(isChecked);
    };

    return <NsCheckbox {...args} checked={isChecked} onChange={handleChange} name="test-checkbox" />;
};
export const Checkbox: Story = {
    render: RenderCheckbox,
    play: ({ canvasElement }) => {
        const canvas = within(canvasElement);
        const el = canvas.getByText(labelText);
        expect(el).toBeInTheDocument();
    },
};
