/**
 * @author [vijayaprathap Kumar] (vpkumar@nuskin.com)
 * @description Styled Components for Checkbox
 */
import DoneIcon from '@mui/icons-material/Done';

import { styled, ColorUtils } from '@nuskin/foundation-theme';
import { NsFlag } from '../flag';
const { paletteColor, buttonColor, getGenomeColor } = ColorUtils;
/**
 * Wrapper BpIcon for checkbox.tsx
 * @params ( theme: { palette }) / Provide the color's to contaier from @nuskin/foundation-theme
 */

export const BpIcon = styled(DoneIcon)(({ theme }) => ({
    border: '1px solid #8C8C8C',
    path: {
        display: 'none',
    },
    'input:hover ~ &': {
        border: '1px solid #94D6E9',
    },
    'input:focus ~ &': {
        outline: '3px solid #94D6E9',
    },
    'input:disabled ~ &': {
        background: buttonColor('primary', 'hovered')({ theme }),
    },
}));

/**
 * Wrapper BpCheckedIcon for checkbox.tsx
 * @params ( theme: { palette }) / Provide the color's to container from @nuskin/foundation-theme
 */

export const BpCheckedIcon = styled(BpIcon)(({ theme }) => ({
    path: {
        display: 'block',
    },
    background: getGenomeColor(theme, 'N100'),
    // background: paletteColor('primary', 'main')({ theme }),
    color: paletteColor('primary', 'contrastText')({ theme }),
}));

const getLabelColor = (isDisabled: boolean, color: string) => (!isDisabled ? '' : `color: ${color}`);

export const StyledLabel = styled('span')<{ isDisabled: boolean }>`
    ${({ isDisabled, theme }) => {
        const color = buttonColor('primary', 'hovered')({ theme });
        return getLabelColor(isDisabled, color);
    }}
`;
export const StyledFlagLabel = styled(NsFlag)`
    margin-right: 16px;
`;
