import { PropsWithChildren } from 'react';

type DivArrayProps = {
    elementsCount: number;
};

const getRandom = (n: number) => (Math.random() * n).toFixed(0);

type DivComponentProps = PropsWithChildren<{ style: Record<string, any>; index: number }>;
export const DivComponent = ({ style, index, children }: DivComponentProps) => {
    const borderWidth = `${getRandom(5)}px`;
    const padding = `${getRandom(20)}px`;
    return (
        <div
            style={{
                padding,
                border: `${borderWidth} solid`,
                borderColor: `hsl(${getRandom(359)},100%, 50%)`,
                background: `hsla(${getRandom(359)},100%, 50%,0.3)`,
                ...style,
            }}
        >
            {index}
            {children}
        </div>
    );
};
/**
 * this component return a fragment containing n number of div, with each div numbered as per its index
 * @param n: number of div to render
 * @returns
 */
export const DivArray = ({ elementsCount }: DivArrayProps) => (
    <>
        {Array(elementsCount)
            .fill(0)
            .map((_, index) => (
                <DivComponent key={index} index={index + 1} style={{}} />
            ))}
    </>
);
export const DivArrayRandom = ({ elementsCount }: DivArrayProps) => (
    <>
        {Array(elementsCount)
            .fill(0)
            .map((_, index) => {
                const width = `${getRandom(700)}px`;
                const height = `${getRandom(400)}px`;
                return (
                    <DivComponent
                        key={index}
                        index={index + 1}
                        style={{
                            width,
                            height,
                        }}
                    >
                        item no = {index + 1} with width = {width} and height = {height}
                    </DivComponent>
                );
            })}
    </>
);
