import React, { useState } from 'react';
import type { Meta, StoryObj } from '@storybook/react';
import { NsDropdown, NsDropdownOption } from '../';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsDropdown;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsDropdown',
    decorators: [withCenterDecorator],
    component: NsDropdown,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        dropdownBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
    },
    parameters: {
        options: [
            { label: 'English', value: 'english', country: 'United States (US)' },
            { label: 'French', value: 'french', country: 'France (FR)' },
            { label: 'German', value: 'german', country: 'Germany (DE)' },
        ],
    },
    args: {
        selectedLabel: 'United States (US) | English',
        type: 'unfilled',
        disabled: false,
        dropdownBorderColor: 'accentColorB',
        closeOnMouseLeave: true,
    },
} as MetaStory;

const RenderStory = (args: any, context: any) => {
    const [selectedLabel, setSelectedLabel] = useState(args.selectedLabel);

    const options = context.parameters.options;
    const handleSelect = (value: string) => {
        options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(`${option.country} | ${option.label}`);
            }
        });
    };

    return (
        <NsDropdown {...args} selectedLabel={selectedLabel} onSelect={handleSelect}>
            {options.map((option: any) => (
                <NsDropdownOption key={option.value} value={option.value}>
                    {option.label}
                </NsDropdownOption>
            ))}
        </NsDropdown>
    );
};
export const DropdownCountry: Story = {
    render: RenderStory,
};
