import { useCallback, useEffect, useState } from 'react';

type ItemMap = Record<string, boolean>;
type UseAccordionProp = {
    allowMultipleExpanded?: boolean;
    defaultOpenIds?: string[];
};
const reducer = (map: ItemMap, id: string) => {
    map[id] = true;
    return map;
};

const useAccordionMap = ({ allowMultipleExpanded, defaultOpenIds }: UseAccordionProp) => {
    const mapSetter = useCallback(() => {
        let ids = defaultOpenIds;
        if (!allowMultipleExpanded) {
            ids = ids?.slice(0, 1) ?? [];
        }
        return ids?.reduce(reducer, {}) ?? {};
    }, [defaultOpenIds, allowMultipleExpanded]);

    const [itemStateMap, setItemMap] = useState<ItemMap>(mapSetter);

    const toggleOpen = (index: string | number) => {
        const key = index + '';
        if (allowMultipleExpanded) {
            setItemMap((prevState) => ({ ...prevState, [key]: !prevState[key] }));
        } else {
            setItemMap({ [key]: !itemStateMap[index] });
        }
    };

    useEffect(() => {
        setItemMap(mapSetter);
    }, [mapSetter]);
    return { itemStateMap, toggleOpen };
};

export default useAccordionMap;
