import { useEffect } from 'react';

export type Handler = () => void;

export function useOnClickOutside(
    element: HTMLDivElement | null,
    handler: Handler = () => {},
    mouseEvent: 'click' | 'mousedown' | 'mouseup' = 'click'
): void {
    useEffect(() => {
        const eventListener = (event: MouseEvent) => {
            // Do nothing if clicking ref's element or descendent elements
            if (!element || element.contains(event.target as Node)) {
                return;
            }
            handler?.();
        };
        if (document) {
            document.addEventListener(mouseEvent, eventListener);
            return () => {
                document.removeEventListener(mouseEvent, eventListener);
            };
        }
    }, [mouseEvent, handler, element]);
}
