import { ReactElement } from 'react';

import {
    FormHelperText,
    TextField,
} from '@mui/material';

import { NsLabel } from '../label';
import {
    AdornmentPropsType,
    getAdornmentProps,
} from './getAdornmentProps';
import InputFieldWrapper from './InputFieldWrapper';
import InputWrapper from './InputWrapper';
import { NsInputFieldProps } from './types.d';

/**
 * we are using fieldState in place of error prop
 * @param props { placeholder, fieldState, iconStart, iconEnd, iconSide }
 * @returns Input Field
 */
const NsInputField = (props: NsInputFieldProps): ReactElement => {
    const {
        autoComplete,
        autoFocus,
        additionalProps,
        defaultValue,
        disabled,
        fullWidth,
        focused,
        id,
        InputProps,
        inputProps,
        inputRef,
        maxRows,
        minRows,
        multiline,
        name,
        onFocus,
        onBlur,
        onChange,
        placeholder,
        required,
        rows,
        ref,
        type,
        value,

        /* custom props */
        fieldState,
        iconStart,
        iconEnd,
        iconSide,
        showOptional,

        /* label props */
        label,
        InputLabelProps,
        labelSize,

        /* helper text props */
        FormHelperTextProps,
        helperText,
        ...rest
    } = props;
    /** EndIcon is created so that we can automatically add success and error icon based of fieldState,
     *  it will override iconEnd. Also to note, InputProps is given to override both iconStart, iconEnd and EndIcon */
    const EndIcon: AdornmentPropsType = getAdornmentProps({ disabled, fieldState, iconEnd, iconStart });
    return (
        <InputFieldWrapper>
            {label ? (
                <NsLabel
                    {...InputLabelProps}
                    size={labelSize as any}
                    showOptional={showOptional}
                    required={required}
                    disabled={disabled}
                    error={fieldState === 'error' && !disabled}
                >
                    {label as any}
                </NsLabel>
            ) : null}
            <InputWrapper fieldState={fieldState} data-testid={additionalProps?.testid ?? 'ns-input-field'}>
                <TextField
                    {...rest}
                    InputProps={{
                        ...EndIcon,
                        ...InputProps,
                    }}
                    {...{
                        autoComplete,
                        autoFocus,
                        defaultValue,
                        disabled,
                        fullWidth,
                        focused,
                        id,
                        inputProps,
                        inputRef,
                        maxRows,
                        minRows,
                        multiline,
                        name,
                        onFocus,
                        onBlur,
                        onChange,
                        placeholder,
                        required,
                        rows,
                        ref,
                        type,
                        value,
                    }}
                />
                {iconSide}
            </InputWrapper>
            {helperText && !disabled ? (
                <FormHelperText {...FormHelperTextProps} className={fieldState}>
                    {helperText}
                </FormHelperText>
            ) : null}
        </InputFieldWrapper>
    );
};
export default NsInputField;
