import React, { ReactElement, useState } from 'react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import type { Meta, StoryObj } from '@storybook/react';

import { NsSelect, NsSelectOption, SelectProps } from '../';
import { countries } from './countries';

type ComponentType = typeof NsSelect;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsSelect',
    decorators: [withCenterDecorator],
    component: NsSelect,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        selectBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
        showListDivider: { control: 'boolean' },
        label: { control: 'text' },
        name: { control: 'text' },
        menuProps: { control: 'text' },
        reverseArrowControls: { control: 'boolean' },
        validateOnBlur: { control: 'boolean' },
        autoComplete: { control: 'text' },
        rules: { control: 'array' },
        hasArrows: { control: 'boolean' },
    },
    parameters: {
        options: countries,
    },
    args: {
        type: 'outlined',
        disabled: false,
        selectBorderColor: 'primary',
        closeOnMouseLeave: false,
        showListDivider: true,
        selected: { label: '', value: '', index: 0 },
        label: 'State',
        placeholder: '',
        name: '',
        menuProps: 'auto',
        reverseArrowControls: false,
        validateOnBlur: false,
        autoComplete: '',
        rules: [],
        hasArrows: false,
    },
} as MetaStory;

const AppSelect = (props: SelectProps): ReactElement => {
    const { selected } = props;

    const [data, setData] = useState(selected);
    const onSelect = (x: any) => {
        setData(x);
    };
    return (
        <NsSelect
            {...props}
            selected={data}
            onSelect={onSelect}
            label={props.label}
            options={props.options}
            RenderOption={(props) => {
                return <NsSelectOption {...props} key={props?.value} onClick={props.onClick} />;
            }}
        />
    );
};
export const Select: Story = {
    render: (args, context) => {
        const options = context.parameters.options;
        return <AppSelect {...args} options={options} />;
    },
};
export const SelectWithArrows: Story = {
    render: (args, context) => {
        const options = context.parameters.options;
        return <AppSelect {...args} options={options} hasArrows />;
    },
};
