import React, { ReactElement } from 'react';

import { TableRow } from '@mui/material';
import Box from '@mui/material/Box';
import Collapse from '@mui/material/Collapse';

import {
    StyledExpandCell,
    StyledOriginalTableCell,
    StyledTableLastCell,
    StyledTableRow,
} from './NsTable.styled';
import type { NsTableRowProps } from './types';

export default function ExpandableRow({
    expandableContent,
    isExpand,
    handleClick,
    row,
    itemKeyList,
    index,
    showActions,
    showExpandedContent,
    actionClick,
}: NsTableRowProps): ReactElement {
    const tableRowTestId = `table-row-${index}`;

    return (
        <React.Fragment>
            <StyledTableRow
                hover
                onClick={() => handleClick(index)}
                tabIndex={-1}
                key={index}
                className="cursor-pointer"
                data-testid={tableRowTestId}
            >
                {itemKeyList.map((id, i) => {
                    return i === itemKeyList.length - 1 && showActions ? (
                        <StyledTableLastCell align="justify" key={id}>
                            <span>{row[id]}</span>
                            <span className="action">{actionClick(row)}</span>
                        </StyledTableLastCell>
                    ) : (
                        <StyledOriginalTableCell align="left" key={id}>
                            {row[id]}
                        </StyledOriginalTableCell>
                    );
                })}
            </StyledTableRow>
            {showExpandedContent ? (
                <TableRow>
                    <StyledExpandCell colSpan={itemKeyList.length} className={!isExpand ? 'remove' : ''}>
                        <Collapse in={isExpand} unmountOnExit>
                            <Box className="m-px">{expandableContent(row, index)}</Box>
                        </Collapse>
                    </StyledExpandCell>
                </TableRow>
            ) : null}
        </React.Fragment>
    );
}
