import React, {
    PropsWithChildren,
    ReactElement,
} from 'react';

import HtmlTagVariantMapping from './HtmlTagVariantMap';
import {
    HtmlTagVariant,
    NsTypographyProps,
} from './types.d';
import { StyledTypography } from './Typography.styled';

const NsTypography = ({
    children,
    weight = 'normal',
    className = '',
    variant = 'body-l',
    decoration = 'none',
    color = 'primary',
    additionalProps = {},
    colorOverride = '',
    noSpacing = false,
    renderHTMLNode,
}: PropsWithChildren<NsTypographyProps>): ReactElement => {
    const htmlTagVariant: HtmlTagVariant | undefined = renderHTMLNode ? HtmlTagVariantMapping[variant] : undefined;

    return (
        <StyledTypography
            noSpacing={noSpacing}
            as={htmlTagVariant}
            className={className}
            weight={weight}
            variant={variant}
            decoration={decoration}
            colorOverride={colorOverride}
            color={color}
            {...additionalProps}
        >
            {children}
        </StyledTypography>
    );
};

export default NsTypography;
